Module map

Module map 

Constant time lookup map implementations where keys implement the Ordinal trait.

Modules

total
Total maps (maps that have a value for every possible key).

Structs

Drain
Iterator that removes all key-value pairs from OrdinalMap or OrdinalArrayMap.
IntoIter
Iterator created from OrdinalMap.
IntoIterArray
Iterator created from OrdinalInitArrayMap.
Iter
Iterator over the entries of OrdinalMap and OrdinalArrayMap.
IterMut
Iterator over mutable references to the entries of OrdinalMap and OrdinalArrayMap.
Keys
Iterator over the keys of OrdinalMap and OrdinalArrayMap.
OccupiedEntry
Reference to the occupied entry in OrdinalMap or OrdinalArrayMap.
OrdinalArrayMap
Map backed by an array, allocated on the stack.
OrdinalMap
Map Ordinal keys to values. Map operations are constant time (provided that K::ordinal() is constant time).
VacantEntry
Reference to the vacant entry in OrdinalMap or OrdinalArrayMap.
Values
Iterator over the values of OrdinalMap and OrdinalArrayMap.

Enums

Entry
Entry API.