OrdinalArrayMap

Struct OrdinalArrayMap 

pub struct OrdinalArrayMap<K, V, const S: usize> { /* private fields */ }
Map backed by an array, allocated on the stack.

Due to Rust limitations, the array size must be provided as a type parameter.

Example

use ordinal_map::map::OrdinalArrayMap;
use ordinal_map::Ordinal;
#[derive(Ordinal)]
enum Weather {
    Sunny,
    Rainy,
    Snowy,
}

let mut map = OrdinalArrayMap::<_, _, { Weather::ORDINAL_SIZE }>::new();
map.insert(Weather::Sunny, "good");
map.insert(Weather::Rainy, "it depends");

This map is sparse (not every key has an associated value). For a total map, see OrdinalTotalMap and OrdinalTotalArrayMap.

Implementations

Source

impl<K: Ordinal, V, const S: usize> OrdinalArrayMap<K, V, S>

pub fn new() -> Self

Create a new map.

pub fn len(&self) -> usize

The number of elements in the map.

This operation is O(K::ORDINAL_SIZE).

pub fn is_empty(&self) -> bool

Return true if the map container no elements.

pub fn get<'a>(&'a self, key: &K) -> Option<&'a V>

Look up a value by key.

pub fn get_mut<'a>(&'a mut self, key: &K) -> Option<&'a mut V>

Look up a value by key.

pub fn contains_key(&self, key: &K) -> bool

Check if the map contains a key.

pub fn insert(&mut self, key: K, value: V) -> Option<V>

Insert a value into the map, returning the previous value if it existed.

pub fn entry(&mut self, key: K) -> Entry<'_, K, V>

Get an entry in the map for the given key.

pub fn remove(&mut self, key: &K) -> Option<V>

Remove a value from the map, returning it if it existed.

pub fn iter<'a>(&'a self) -> Iter<'a, K, V>

Iterate over the map.

pub fn iter_mut<'a>(&'a mut self) -> IterMut<'a, K, V>

Iterate over the map mutably.

pub fn keys(&self) -> Keys<'_, K, V>

Iterate over the keys of the map.

pub fn values(&self) -> Values<'_, K, V>

Iterate over the values of the map.

pub fn values_mut(&mut self) -> ValuesMut<'_, K, V>

Iterate over the values of the map mutably.

pub fn drain(&mut self) -> Drain<'_, K, V>

Remove all elements from the map.

pub fn clear(&mut self)

Remove all elements from the map.

pub fn retain<F>(&mut self, f: F)
where F: FnMut(K, &mut V) -> bool,

Retain only the elements specified by the predicate.