OrdinalTotalMap

Struct OrdinalTotalMap 

pub struct OrdinalTotalMap<T, V> { /* private fields */ }
Map implementation where all values must be initialized at creation.

This version of map allocates values on the heap in a single contiguous block. For a version that doesn’t require heap allocation, see InitArrayMap.

Implementations

Source

impl<K: Ordinal, V> OrdinalTotalMap<K, V>

pub fn try_new<E>(init: impl FnMut(K) -> Result<V, E>) -> Result<Self, E>

Create a new map by initializing each value with a function.

pub fn new(init: impl FnMut(K) -> V) -> Self

Create a new map by initializing each value with a function.

pub const fn len(&self) -> usize

Returns the number of elements in the map, which is always equal to K::ORDINAL_SIZE.

pub const fn is_empty(&self) -> bool

Return true if the map container no elements. This is only if <K> is empty.

pub fn get<'a>(&'a self, key: &K) -> &'a V

Returns a reference to the value corresponding to the key.

pub fn get_mut<'a>(&'a mut self, key: &K) -> &'a mut V

Returns a mutable reference to the value corresponding to the key.

pub fn keys(&self) -> OrdinalValues<K>

Iterate keys of the map, which is equivalent to iterating all possible values of K.

pub fn into_keys(self) -> OrdinalValues<K>

Iterate values of the map, which is equivalent to iterating all possible values of K.

pub fn values<'a>(&'a self) -> Iter<'a, V>

Iterate values of the map.

pub fn values_mut<'a>(&'a mut self) -> IterMut<'a, V>

Iterate mutable references to values of the map.

pub fn into_values(self) -> Box<[V]>

Obtain the values from the map.

pub fn iter<'a>(&'a self) -> Iter<'a, K, V>

Iterate over the map.

pub fn iter_mut<'a>(&'a mut self) -> IterMut<'a, K, V>

Iterate over the map mutably.

pub fn insert(&mut self, key: K, value: V) -> V

Insert a value into the map, returning the previous value.