Module set

Module set 

Constant time lookup set implementations where entries implement the Ordinal trait.

Structs

Iter
Iterator over elements of OrdinalSet or OrdinalArraySet.
Iter64
Iterator over OrdinalSet64.
OrdinalArraySet
Set of ordinals implemented as an array of words.
OrdinalSet
Default set implementation.
OrdinalSet64
Set for implementations of Ordinal with a maximum ordinal size of 64.

Functions

ordinal_array_set_s
Compute the size of S parameter for OrdinalArraySet. This is simply (T::ORDINAL_SIZE + 63) / 64.