OrdinalArraySet

Struct OrdinalArraySet 

pub struct OrdinalArraySet<T, const S: usize> { /* private fields */ }
Set of ordinals implemented as an array of words.

Size parameter

Parameter S must be explicitly specified as ordinal_array_set_s::<T>() due to limitations of const generics in stable Rust.

If this is not convenient, consider using:

Example

use ordinal_map::set::ordinal_array_set_s;
use ordinal_map::set::OrdinalArraySet;
let mut set: OrdinalArraySet<u8, { ordinal_array_set_s::<u8>() }> = OrdinalArraySet::new();

set.insert(17);

Implementations

Source

impl<T: Ordinal, const S: usize> OrdinalArraySet<T, S>

pub fn new() -> Self

Create a new empty set.

pub fn contains(&self, ordinal: &T) -> bool

Check if the set contains an ordinal.

pub fn insert(&mut self, ordinal: T) -> bool

Insert an ordinal into the set, returning true if the ordinal was not already present.