OrdinalSet

Struct OrdinalSet 

pub struct OrdinalSet<T> { /* private fields */ }
Default set implementation.

All operations are constant time (provided that T::ordinal() is constant time).

This map allocates memory when the number of elements is greater than 64. When the number of elements is known to be less than or equal to 64, consider using Set64 instead.

Implementations

Source

impl<T: Ordinal> OrdinalSet<T>

pub fn new() -> Self

Create a new empty set.

pub fn contains(&self, ordinal: &T) -> bool

Check if the set contains an element.

pub fn insert(&mut self, ordinal: T) -> bool

Insert an element into the set, returning true if the element was not already present.

pub fn iter(&self) -> Iter<'_, T>

Iterate over the elements of the set.