pub struct OrdinalSet64<T> { /* private fields */ }Expand description
Set for implementations of Ordinal with a maximum ordinal size of 64.
This is implemented using a single u64 value to store the set of elements.
To store set of arbitrary size, consider using OrdinalSet.
Implementations