Constant time lookup map implementations where keys implement
the Ordinal trait.
Modules
- total
- Total maps (maps that have a value for every possible key).
Structs
- Drain
- Iterator that removes all key-value pairs from
OrdinalMaporOrdinalArrayMap. - Into
Iter - Iterator created from
OrdinalMap. - Into
Iter Array - Iterator created from
OrdinalInitArrayMap. - Iter
- Iterator over the entries of
OrdinalMapandOrdinalArrayMap. - IterMut
- Iterator over mutable references to the entries of
OrdinalMapandOrdinalArrayMap. - Keys
- Iterator over the keys of
OrdinalMapandOrdinalArrayMap. - Occupied
Entry - Reference to the occupied entry in
OrdinalMaporOrdinalArrayMap. - Ordinal
Array Map - Map backed by an array, allocated on the stack.
- Ordinal
Map - Map
Ordinalkeys to values. Map operations are constant time (provided thatK::ordinal()is constant time). - Vacant
Entry - Reference to the vacant entry in
OrdinalMaporOrdinalArrayMap. - Values
- Iterator over the values of
OrdinalMapandOrdinalArrayMap.
Enums
- Entry
- Entry API.