OrdinalMap

Struct OrdinalMap 

pub struct OrdinalMap<K, V> { /* private fields */ }
Map Ordinal keys to values. Map operations are constant time (provided that K::ordinal() is constant time).

This implementation allocates a boxed slice [Option<V>; K::ORDINAL_SIZE] on the first insertion. For non-allocating map, consider using OrdinalArrayMap.

This implementation is sparse (not every key has an associated value). For a total map, see OrdinalTotalMap and OrdinalTotalArrayMap.

Implementations

Source

impl<K: Ordinal, V> OrdinalMap<K, V>

pub fn new() -> Self

Create a new empty map. This operation does not allocate memory, but first insertion allocates the whole map.

pub fn get<'a>(&'a self, key: &K) -> Option<&'a V>

Returns a reference to the value corresponding to the key.

pub fn get_mut<'a>(&'a mut self, key: &K) -> Option<&'a mut V>

Returns a mutable reference to the value corresponding to the key.

pub fn contains_key(&self, key: &K) -> bool

Returns true if the map contains the key.

pub fn len(&self) -> usize

Returns the number of elements in the map. This is an O(K::ORDINAL_SIZE) operation.

pub fn is_empty(&self) -> bool

Return true if the map container no elements.

pub fn insert(&mut self, key: K, value: V) -> Option<V>

Insert a value into the map, returning the previous value if it existed.

pub fn entry(&mut self, key: K) -> Entry<'_, K, V>

Get an entry in the map for the given key.

pub fn remove(&mut self, key: &K) -> Option<V>

Remove a value from the map, returning it if it existed.

pub fn iter(&self) -> Iter<'_, K, V>

Iterate over the map.

pub fn iter_mut(&mut self) -> IterMut<'_, K, V>

Iterate over the map mutably.

pub fn keys(&self) -> Keys<'_, K, V>

Iterate over the keys of the map.

pub fn values(&self) -> Values<'_, K, V>

Iterate over the values of the map.

pub fn values_mut(&mut self) -> ValuesMut<'_, K, V>

Iterate over the mutable references to the values of the map.

pub fn drain(&mut self) -> Drain<'_, K, V>

Clears the map, returning all key-value pairs as an iterator.

pub fn clear(&mut self)

Remove all elements from the map.