pub struct OrdinalSet<T> { /* private fields */ }Expand description
Default set implementation.
All operations are constant time
(provided that T::ordinal() is constant time).
This map allocates memory when the number of elements is greater than 64.
When the number of elements is known to be less than or equal to 64,
consider using Set64 instead.
Implementations